<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr">
<context>
    <name>App.About</name>
    <message>
        <location filename="../main.cpp" line="101"/>
        <location filename="../main.cpp" line="105"/>
        <source>System Monitor</source>
        <translation>Праћење Система</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Праћење Система је алат за надзирање оптерећења система у реалном времену и управљање системским процесима и услугама.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="29"/>
        <source>Hide details</source>
        <translation>Сакриј детаље</translation>
    </message>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="40"/>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="52"/>
        <source>Overall utilization</source>
        <translation>Укупна употреба</translation>
    </message>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="43"/>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="54"/>
        <source>Individual utilization</source>
        <translation>Индивидуална употреба</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <location filename="../gui/block_dev_item_widget.cpp" line="154"/>
        <source>Read</source>
        <translation>Читање</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_item_widget.cpp" line="158"/>
        <source>Write</source>
        <translation>Уписивање</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <location filename="../gui/cpu_detail_widget.cpp" line="168"/>
        <location filename="../gui/cpu_detail_widget.cpp" line="285"/>
        <source>60 seconds</source>
        <translation>60 секунди</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <location filename="../model/cpu_info_model.cpp" line="49"/>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 дана %2 сат. %3 мин.</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="91"/>
        <source>Utilization</source>
        <translation>Употреба</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="93"/>
        <source>Frequency</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="98"/>
        <source>Max frequency</source>
        <translation>Frequency</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="100"/>
        <source>Average frequency</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="104"/>
        <source>Up time</source>
        <translation>Време у раду</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="106"/>
        <source>Sockets</source>
        <translation>Лежишта</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="110"/>
        <source>Logical processors</source>
        <translation>Логички процесори</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="112"/>
        <source>Virtualization</source>
        <translation>Виртуелизација</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="116"/>
        <source>L1i cache</source>
        <translation>L1i кеш</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="118"/>
        <source>L1d cache</source>
        <translation>L1d кеш</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="122"/>
        <source>L2 cache</source>
        <translation>L2 кеш</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="124"/>
        <source>L3 cache</source>
        <translation>L3 кеш</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="128"/>
        <source>Load average</source>
        <translation>Просечно оптерећање</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="130"/>
        <source>File descriptors</source>
        <translation>Дескриптори датотека</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="134"/>
        <source>Processes</source>
        <translation>Процеси</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="136"/>
        <source>Threads</source>
        <translation>Нити</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="140"/>
        <source>Host name</source>
        <translation>Име домаћина</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="142"/>
        <source>OS type</source>
        <translation>Врста ОС-а</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="146"/>
        <source>Version</source>
        <translation>Верзија</translation>
    </message>
</context>
<context>
    <name>Cancel</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="310"/>
        <source>Cancel</source>
        <translation type="unfinished">Откажи</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <location filename="../gui/chart_view_widget.cpp" line="321"/>
        <source>60 seconds</source>
        <translation>60 секунди</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="493"/>
        <location filename="../gui/system_service_table_view.cpp" line="476"/>
        <source>No search results</source>
        <translation>Нема резултата претраге</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <location filename="../compact_cpu_monitor.cpp" line="89"/>
        <source>Details</source>
        <translation>Детаљи</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <location filename="../cpu_monitor.cpp" line="72"/>
        <source>Details</source>
        <translation>Детаљи</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="165"/>
        <source>active</source>
        <translation>активно</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="167"/>
        <source>reloading</source>
        <translation>учитавање</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="169"/>
        <source>inactive</source>
        <translation>неактивно</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="170"/>
        <source>failed</source>
        <translation>отказао</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="172"/>
        <source>activating</source>
        <translation>активирање</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="174"/>
        <source>deactivating</source>
        <translation>деактивирање</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="146"/>
        <source>stub</source>
        <translation>stub</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="149"/>
        <source>not-found</source>
        <translation>није-пронађено</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="151"/>
        <source>bad-setting</source>
        <translation>лоше-подешено</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="152"/>
        <source>error</source>
        <translation>грешка</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="153"/>
        <source>merged</source>
        <translation>спојено</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="154"/>
        <source>masked</source>
        <translation>маскирано</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="147"/>
        <source>loaded</source>
        <translation>учитавање</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="297"/>
        <source>N/A</source>
        <translation>Н/П</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="295"/>
        <source>Auto</source>
        <translation>Ауто.</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="296"/>
        <source>Manual</source>
        <translation>Ручно</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="274"/>
        <source>enabled</source>
        <translation>омогућено</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="275"/>
        <source>disabled</source>
        <translation>онемогућено</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="276"/>
        <source>static</source>
        <translation>статично</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="277"/>
        <source>transient</source>
        <translation>несталан</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="278"/>
        <source>indirect</source>
        <translation>индиректно</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="280"/>
        <source>enabled-runtime</source>
        <translation>омогућено-извршавање</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="281"/>
        <source>masked</source>
        <translation>маскирано</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="283"/>
        <source>generated</source>
        <translation>генерисано</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="217"/>
        <source>dead</source>
        <translation>мртво</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="219"/>
        <source>start-pre</source>
        <translation>start-pre</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="221"/>
        <source>start</source>
        <translation>start</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="223"/>
        <source>start-post</source>
        <translation>start-post</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="225"/>
        <source>running</source>
        <translation>ради</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="227"/>
        <source>exited</source>
        <translation>изашао</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="229"/>
        <source>reload</source>
        <translation>reload</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="231"/>
        <source>stop</source>
        <translation>stop</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="233"/>
        <source>stop-watchdog</source>
        <translation>stop-watchdog</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="235"/>
        <source>stop-sigterm</source>
        <translation>stop-sigterm</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="237"/>
        <source>stop-sigkill</source>
        <translation>stop-sigkill</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="239"/>
        <source>stop-post</source>
        <translation>stop-post</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="241"/>
        <source>final-sigterm</source>
        <translation>final-sigterm</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="243"/>
        <source>final-sigkill</source>
        <translation>final-sigkill</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="245"/>
        <source>failed</source>
        <translation>отказао</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="247"/>
        <source>auto-restart</source>
        <translation>auto-restart</translation>
    </message>
</context>
<context>
    <name>DBusAlarmNotify</name>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="38"/>
        <location filename="../dbus/dbusalarmnotify.cpp" line="50"/>
        <source>Warning</source>
        <translation>Предупреди</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="39"/>
        <source>Your CPU usage is higher than %1%!</source>
        <translation>Ваша употреба ЦП је већа од %1%!</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="51"/>
        <source>Your memory usage is higher than %1%!</source>
        <translation>Ваша употреба памети је већа од %1%!</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="71"/>
        <source>View</source>
        <translation type="unfinished">Приказ</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="67"/>
        <source>Used</source>
        <translation>Заузето</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="69"/>
        <source>Available</source>
        <translation>Слободно</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="73"/>
        <source>Shared</source>
        <translation>Дељено</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="75"/>
        <source>Cached</source>
        <translation>Кеширано</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="79"/>
        <source>Buffers</source>
        <translation>Попуне</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="81"/>
        <source>Cached swap</source>
        <translation>Кеширана помоћна мем.</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="85"/>
        <source>Active</source>
        <translation>Активност</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="87"/>
        <source>Inactive</source>
        <translation>Неактивно</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="91"/>
        <source>Dirty</source>
        <translation>Прљаво</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="93"/>
        <source>Mapped</source>
        <translation>Пресликано</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="97"/>
        <source>Total swap</source>
        <translation>Укупна помоћна мем.</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="99"/>
        <source>Free swap</source>
        <translation>Слободна помоћна мем.</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="103"/>
        <source>Slab</source>
        <translation>Плоча</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="70"/>
        <source>Model</source>
        <translation>Модел</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="72"/>
        <source>Read speed</source>
        <translation>Брзина читања</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="76"/>
        <source>Write speed</source>
        <translation>Брзина уписивања</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="78"/>
        <source>Capacity</source>
        <translation>Капацитет</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="82"/>
        <source>Sectors read</source>
        <translation>Читања сектора</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="84"/>
        <source>Reads/s</source>
        <translation>Читања/сек</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="88"/>
        <source>Sectors read/s</source>
        <translation>Читања сектора/сек</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="90"/>
        <source>Reads merged/s</source>
        <translation>Читања спојено/сек</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="94"/>
        <source>Sectors written</source>
        <translation>Уписаних сектора</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="96"/>
        <source>Writes completed </source>
        <translation>Завршених уписивања </translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="100"/>
        <source>Writes merged</source>
        <translation>Уписивања спојено </translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="102"/>
        <source>Writes/s</source>
        <translation>Уписивања/сек</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="106"/>
        <source>Sectors written/s</source>
        <translation>Уписаних сектора/сек</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="108"/>
        <source>Writes merged/s</source>
        <translation>Читања спојено/сек</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <location filename="../gui/dialog/error_dialog.cpp" line="73"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>У реду</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <location filename="../common/common.cpp" line="32"/>
        <source>System</source>
        <translation>Систем</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="38"/>
        <source>Display shortcuts</source>
        <translation>Прикажи пречице</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="173"/>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Окончање овог процеса може изазвати губитак података.
Заиста желите да наставите?</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="530"/>
        <location filename="../gui/process_table_view.cpp" line="172"/>
        <location filename="../gui/process_table_view.cpp" line="379"/>
        <source>End process</source>
        <translation>Окончај процес</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="380"/>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Принудно окончање овог процеса може изазвати губитак података.
Заиста желите да наставите?</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="531"/>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Принудно окончање овог програма може изазвати губитак података.
Заиста желите да наставите?</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="539"/>
        <location filename="../gui/process_table_view.cpp" line="179"/>
        <location filename="../gui/process_table_view.cpp" line="387"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Откажи</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="540"/>
        <location filename="../gui/process_table_view.cpp" line="388"/>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Принудно окончај</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="180"/>
        <source>End</source>
        <comment>button</comment>
        <translation>Окончај</translation>
    </message>
</context>
<context>
    <name>Logout</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="311"/>
        <source>Logout</source>
        <translation>Одјави се</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../gui/main_window.cpp" line="181"/>
        <source>Settings</source>
        <translation>Подешавање</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <location filename="../gui/mem_stat_view_widget.cpp" line="52"/>
        <source>Size</source>
        <translation>Величина</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <location filename="../gui/netif_summary_view_widget.h" line="159"/>
        <source>IP address:</source>
        <translation>ИП адреса:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <source>Netmask:</source>
        <translation>Мрежна маска:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <source>Broadcast:</source>
        <translation>Емитовање:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="159"/>
        <source>Prefixlen:</source>
        <translation>Префикслен:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="159"/>
        <source>Scope:</source>
        <translation>Опсег:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="293"/>
        <source>Connection type</source>
        <translation>Врста везе</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="301"/>
        <source>ESSID</source>
        <translation>ЕССИД</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="307"/>
        <source>Link quality</source>
        <translation>Квалитет везе</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="312"/>
        <source>Signal strength</source>
        <translation>Јачина сигнала</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="317"/>
        <source>Noise level</source>
        <translation>Ниво шума</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="323"/>
        <source>MAC</source>
        <translation>МАК</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="328"/>
        <source>Bandwidth</source>
        <translation>Пропусни опсег</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="333"/>
        <source>RX packets</source>
        <translation>RX пакети</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="338"/>
        <source>RX bytes</source>
        <translation>RX бајтови</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="343"/>
        <source>RX errors</source>
        <translation>RX грешке</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="348"/>
        <source>RX dropped</source>
        <translation>RX одбачено</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="353"/>
        <source>RX overruns</source>
        <translation>RX прекорачења</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="358"/>
        <source>RX frame</source>
        <translation>RX оквир</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="363"/>
        <source>TX packets</source>
        <translation>TX пакети</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="368"/>
        <source>TX bytes</source>
        <translation>TX бајтови</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="373"/>
        <source>TX errors</source>
        <translation>TX грешке</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="383"/>
        <source>TX overruns</source>
        <translation>TX прекорачења</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="388"/>
        <source>TX carrier</source>
        <translation>TX носилац</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="267"/>
        <location filename="../gui/netif_summary_view_widget.h" line="269"/>
        <source>IPv4</source>
        <translation>ИПв4</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="282"/>
        <location filename="../gui/netif_summary_view_widget.h" line="284"/>
        <source>IPv6</source>
        <translation>ИПв6</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="378"/>
        <source>TX dropped</source>
        <translation>TX одбачено</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="143"/>
        <source>Command line</source>
        <translation>Командна линија</translation>
    </message>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="148"/>
        <source>Start time</source>
        <translation>Почетно време</translation>
    </message>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="138"/>
        <source>Name</source>
        <translation>Име</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <location filename="../gui/xwin_kill_preview_background_widget.cpp" line="152"/>
        <source>Click the application you want to end</source>
        <translation>Кликните на програм који желите да окончате</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="183"/>
        <location filename="../gui/mem_detail_view_widget.cpp" line="25"/>
        <location filename="../gui/mem_stat_view_widget.cpp" line="107"/>
        <location filename="../memory_monitor.cpp" line="177"/>
        <source>Memory</source>
        <translation>Меморија</translation>
    </message>
    <message>
        <location filename="../gui/netif_item_view_widget.cpp" line="95"/>
        <location filename="../gui/netif_item_view_widget.cpp" line="121"/>
        <source>Receive</source>
        <translation>Примање</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <location filename="../compact_cpu_monitor.cpp" line="233"/>
        <location filename="../cpu_monitor.cpp" line="233"/>
        <location filename="../cpu_monitor.cpp" line="242"/>
        <location filename="../gui/cpu_detail_widget.cpp" line="371"/>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="182"/>
        <source>CPU</source>
        <translation>ЦПЈ</translation>
    </message>
    <message>
        <location filename="../compact_disk_monitor.cpp" line="153"/>
        <source>Disk read</source>
        <translation>Читање диска</translation>
    </message>
    <message>
        <location filename="../compact_disk_monitor.cpp" line="154"/>
        <source>Disk write</source>
        <translation>Уписивање диска</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="191"/>
        <location filename="../memory_monitor.cpp" line="203"/>
        <source>Memory</source>
        <translation>Меморија</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="203"/>
        <location filename="../compact_memory_monitor.cpp" line="210"/>
        <location filename="../gui/mem_stat_view_widget.cpp" line="115"/>
        <location filename="../memory_monitor.cpp" line="214"/>
        <location filename="../memory_monitor.cpp" line="221"/>
        <source>Swap</source>
        <translation>Помоћна</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="204"/>
        <location filename="../memory_monitor.cpp" line="215"/>
        <source>Not enabled</source>
        <translation>Није омогућено</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="158"/>
        <location filename="../network_monitor.cpp" line="216"/>
        <source>Download</source>
        <translation>Преузимање</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="163"/>
        <location filename="../network_monitor.cpp" line="221"/>
        <source>Upload</source>
        <translation>Отпремање</translation>
    </message>
    <message>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="184"/>
        <location filename="../gui/netif_detail_view_widget.cpp" line="28"/>
        <location filename="../network_monitor.cpp" line="198"/>
        <source>Network</source>
        <translation>Мрежа</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="160"/>
        <location filename="../network_monitor.cpp" line="218"/>
        <source>Total Received</source>
        <translation>Преузето</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="165"/>
        <location filename="../network_monitor.cpp" line="223"/>
        <source>Total Sent</source>
        <translation>Отпремљено</translation>
    </message>
    <message>
        <location filename="../gui/netif_item_view_widget.cpp" line="104"/>
        <location filename="../gui/netif_item_view_widget.cpp" line="130"/>
        <source>Send</source>
        <translation>Слање</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_detail_view_widget.cpp" line="21"/>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="185"/>
        <source>Disks</source>
        <translation>Дискови</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="67"/>
        <source>Loading</source>
        <translation>Учитавање</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="633"/>
        <location filename="../process/process.cpp" line="55"/>
        <source>Very high</source>
        <translation>Веома висок</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="641"/>
        <location filename="../process/process.cpp" line="56"/>
        <source>High</source>
        <translation>Висок</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="649"/>
        <location filename="../process/process.cpp" line="57"/>
        <source>Normal</source>
        <translation>Нормалан</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="657"/>
        <location filename="../process/process.cpp" line="58"/>
        <source>Low</source>
        <translation>Низак</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="665"/>
        <location filename="../process/process.cpp" line="59"/>
        <source>Very low</source>
        <translation>Веома низак</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="673"/>
        <location filename="../process/process.cpp" line="60"/>
        <source>Custom</source>
        <translation>Прилагођен</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="61"/>
        <source>Invalid</source>
        <translation>Неважеће</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="199"/>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>ПИД: %1, Грешка: [%2] %3</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="156"/>
        <location filename="../process/process_db.cpp" line="196"/>
        <source>Failed to change process priority</source>
        <translation>Неуспешна промена приоритета процеса</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="61"/>
        <source>Applications</source>
        <translation>Програми</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="63"/>
        <source>My processes</source>
        <translation>Моји процеси</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="65"/>
        <source>All processes</source>
        <translation>Сви процеси</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <location filename="../process/process_db.cpp" line="267"/>
        <source>Failed to pause process</source>
        <translation>Неуспешно паузирање процеса</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="270"/>
        <source>Failed to resume process</source>
        <translation>Неуспешно настављање процеса</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="273"/>
        <source>Failed to kill process</source>
        <translation>Убијање процеса није успело</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="276"/>
        <source>Unknown error</source>
        <translation>Непозната грешка</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="337"/>
        <source>Failed in sending signal to process</source>
        <translation>Неуспешно слање сигнала ка процесу</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="264"/>
        <source>Failed to end process</source>
        <translation>Окончавање процеса није успело</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="58"/>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 програм/а %2 процес/а у раду)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <location filename="../model/process_table_model.cpp" line="269"/>
        <source>No response</source>
        <translation>Нема одговора</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.cpp" line="275"/>
        <source>Suspend</source>
        <translation>Обустављено</translation>
    </message>
    <message>
        <location filename="../process/process_name.cpp" line="90"/>
        <location filename="../process/process_name.cpp" line="99"/>
        <location filename="../process/process_name.cpp" line="104"/>
        <source>Tray</source>
        <translation>Касета</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="680"/>
        <source>View command location</source>
        <translation>Прикажи локацију команде</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="83"/>
        <location filename="../gui/process_table_view.cpp" line="684"/>
        <source>Properties</source>
        <translation>Својства</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="66"/>
        <location filename="../gui/process_table_view.cpp" line="608"/>
        <source>End process</source>
        <translation>Окончај процес</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="78"/>
        <location filename="../gui/process_table_view.cpp" line="620"/>
        <source>Resume process</source>
        <translation>Настави процес</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="89"/>
        <location filename="../gui/process_table_view.cpp" line="691"/>
        <source>Kill process</source>
        <translation>Убиј процес</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="627"/>
        <source>Change priority</source>
        <translation>Промени приоритет</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="72"/>
        <location filename="../gui/process_table_view.cpp" line="614"/>
        <source>Suspend process</source>
        <translation>Обустави процес</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1052"/>
        <source>Custom Priority</source>
        <translation>Прилагођени приоритет</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1085"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Откажи</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1087"/>
        <source>Change</source>
        <comment>button</comment>
        <translation>Промени</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <location filename="../model/process_table_model.h" line="16"/>
        <source>Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="18"/>
        <source>CPU</source>
        <translation>ЦПЈ</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="22"/>
        <source>Memory</source>
        <translation>Меморија</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="32"/>
        <source>Disk write</source>
        <translation>Уписивање диска</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="30"/>
        <source>Disk read</source>
        <translation>Читање диска</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="28"/>
        <source>Download</source>
        <translation>Преузимање</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="26"/>
        <source>Upload</source>
        <translation>Отпремање</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="34"/>
        <source>PID</source>
        <translation>ПИД</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="20"/>
        <source>User</source>
        <translation>Корисник</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="36"/>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="38"/>
        <source>Priority</source>
        <translation>Приоритет</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="23"/>
        <source>Shared memory</source>
        <translation>Дељена меморија</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="24"/>
        <source>Virtual memory</source>
        <translation>Виртуелна меморија</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../system/cpu_set.cpp" line="426"/>
        <source>Not support</source>
        <translation>Неподржано</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="10"/>
        <source>Settings</source>
        <translation>Подешавање</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="11"/>
        <source>System Protection</source>
        <translation>Заштита система</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="12"/>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>Прикажи предупредбе када се употреба превеличава од порочних вредности</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="13"/>
        <source>CPU warning threshold (%)</source>
        <translation>Порочна вредност предупредбе за ЦП (%)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="14"/>
        <source>Memory warning threshold (%)</source>
        <translation>Порочна вредност предупредбе за памет (%)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="15"/>
        <source>Warning interval (min)</source>
        <translation>Интервал предупредби (мин)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="16"/>
        <source>Notifications</source>
        <translation>Обавештења</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <location filename="../service/service_manager.cpp" line="342"/>
        <source>Failed to set service startup type</source>
        <translation>Неуспешна поставка режима покретања услуге</translation>
    </message>
    <message>
        <location filename="../service/service_manager.cpp" line="408"/>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Грешка: Неуспешна поставка режима покретања услуге због отказа под-процеса</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="157"/>
        <location filename="../gui/system_service_table_view.cpp" line="224"/>
        <location filename="../gui/system_service_table_view.cpp" line="292"/>
        <source>Service instance name</source>
        <translation>Назив инстанце услуге</translation>
    </message>
    <message>
        <location filename="../gui/service_name_sub_input_dialog.cpp" line="38"/>
        <source>OK</source>
        <translation>У реду</translation>
    </message>
    <message>
        <location filename="../gui/service_name_sub_input_dialog.cpp" line="39"/>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="118"/>
        <location filename="../gui/system_service_table_view.cpp" line="562"/>
        <source>Refresh</source>
        <translation>Освежи</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="103"/>
        <location filename="../gui/system_service_table_view.cpp" line="542"/>
        <source>Start</source>
        <translation>Покрени</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="108"/>
        <location filename="../gui/system_service_table_view.cpp" line="547"/>
        <source>Stop</source>
        <translation>Заустави</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="113"/>
        <location filename="../gui/system_service_table_view.cpp" line="552"/>
        <source>Restart</source>
        <translation>Поново покрени</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="558"/>
        <source>Auto</source>
        <translation>Ауто.</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="559"/>
        <source>Manual</source>
        <translation>Ручно</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="557"/>
        <source>Startup type</source>
        <translation>Режим покретања</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <location filename="../model/system_service_table_model.h" line="16"/>
        <source>Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="18"/>
        <source>Load</source>
        <translation>Учитај</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="23"/>
        <source>Sub</source>
        <translation>Подстање</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="30"/>
        <source>Description</source>
        <translation>Опис</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="32"/>
        <source>PID</source>
        <translation>ПИД</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="27"/>
        <source>Startup Type</source>
        <translation>Режим покретања</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="21"/>
        <source>Start State</source>
        <translation>Стартно стање</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="25"/>
        <source>Start Tactic</source>
        <translation>Стартна тактика</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="132"/>
        <source>Settings</source>
        <translation>Подешавање</translation>
    </message>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="165"/>
        <source>(Modifiable)</source>
        <translation>(Модификујући)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="278"/>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="387"/>
        <source>Range: %1-%2</source>
        <translation>Обим: %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="59"/>
        <location filename="../gui/main_window.cpp" line="129"/>
        <source>Force end application</source>
        <translation>Принудно окончај програм</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="147"/>
        <source>Expand</source>
        <translation>Проширено</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="150"/>
        <source>Compact</source>
        <translation>Збијено</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="142"/>
        <source>View</source>
        <translation>Приказ</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <location filename="../common/common.cpp" line="44"/>
        <location filename="../gui/toolbar.cpp" line="95"/>
        <source>Search</source>
        <translation>Претражи</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <location filename="../common/common.cpp" line="53"/>
        <location filename="../gui/main_window.cpp" line="224"/>
        <location filename="../gui/main_window.cpp" line="235"/>
        <location filename="../gui/toolbar.cpp" line="45"/>
        <source>Processes</source>
        <translation>Процеси</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="98"/>
        <location filename="../gui/main_window.cpp" line="224"/>
        <location filename="../gui/main_window.cpp" line="235"/>
        <location filename="../gui/main_window.cpp" line="245"/>
        <location filename="../gui/toolbar.cpp" line="53"/>
        <source>Services</source>
        <translation>Услуге</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="245"/>
        <location filename="../gui/toolbar.cpp" line="60"/>
        <source>Users</source>
        <translation>Корисници</translation>
    </message>
</context>
<context>
    <name>User.Account.Operation</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="102"/>
        <source>Edit account information</source>
        <translation>Уреди информације о налогу</translation>
    </message>
</context>
<context>
    <name>User.Account.Type</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="152"/>
        <source>Administrator</source>
        <translation>Администратор</translation>
    </message>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="152"/>
        <source>Standard User</source>
        <translation>Стандардни корисник</translation>
    </message>
</context>
</TS>
